package
Version:
v0.0.0-...-a9f4370
Opens a new window with list of versions in this module.
Published: Feb 22, 2023
License: GPL-3.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
BaseUrl string `json:"baseurl"`
AccountPath string `json:"account"`
CvePath string `json:"cve"`
CwePath string `json:"cwe"`
VendorsPath string `json:"vendors"`
ReportsPath string `json:"reports"`
AlertsPath string `json:"alerts"`
}
type Credentials struct {
Username string `json:"user"`
Password string `json:"pass"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.